#
# spec file for package python-autoflake
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-autoflake
Version:        2.3.1
Release:        2.1
Summary:        Program to removes unused Python imports and variables
License:        MIT
URL:            https://github.com/myint/autoflake
Source:         https://files.pythonhosted.org/packages/source/a/autoflake/autoflake-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyflakes >= 3.0.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-pyflakes >= 3.0.0
Requires:       python-tomli
BuildArch:      noarch
%python_subpackages

%description
Autoflake removes unused imports and unused variables from Python
code. It makes use of pyflakes to do this.

By default, autoflake only removes unused imports for modules that
are part of the standard library. (Other modules may have side
effects that make them unsafe to remove automatically.) Removal of
unused variables is also disabled by default.

autoflake also removes useless pass statements.

%prep
%autosetup -p1 -n autoflake-%{version}
sed -i '1{/env python/d}' autoflake.py
chmod -x autoflake.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand rm %{buildroot}%{$python_sitelib}/{LICENSE,README.md,test*.py,__pycache__/test*.pyc}
%python_clone -a %{buildroot}%{_bindir}/autoflake
%fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pyunittest -v test_autoflake

%pre
%python_libalternatives_reset_alternative autoflake

%files %{python_files}
%doc AUTHORS.rst README.md
%license LICENSE
%python_alternative %{_bindir}/autoflake
%{python_sitelib}/autoflake.py*
%pycache_only %{python_sitelib}/__pycache__/autoflake*.pyc
%{python_sitelib}/autoflake-%{version}*-info

%changelog
* Mon Jun 16 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Fri Nov  8 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.3.1
  * Update pre-commit config
  * github/workflows/main: use pre-commit/action
  * Always set encoding when reading setup.cfg
- from version 2.3.0
  * readme: add note about customizing args in pre-commit
  * Add Python 3.12 to CI
  * Update pre-commit config
  * Add support for passing the .toml config in the arguments
  * Add support of ignore comment on the top of the file
- Drop support-python312.patch, merged upstream
* Wed Aug 14 2024 Dirk Müller <dmueller@suse.com>
- switch to modern python on sle15
* Tue Feb  6 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add upstream support-python312.patch gh#PyCQA/autoflake#280
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 2.2.1:
  * Add type annotations and validate with pyright
  * Remove test_fuzz_pypi
  * Revert "Support .toml configuration format with --config flag
  * Support .toml configuration format with --config flag
  * Fix a typo in a link to pre-commit
  * Update standard_paths so it only checks existing directories
  * Upgrade minimum version of pyflakes
  * Add upper limit to pyflake's version <3.0 to support handling
    of python 2.x
  * fix: Ignore pass multiple lines after docstring with flag
  * Fixed multiprocessing issue on win64 with more than 60 cores
  * Fix default value for `--imports`
  * Use regular dictionary instead of defaultdict
  * Properly consider options from config file and flags
  * Update merge_configuration_file to prefer values from flags
  * Unified output to stdout when using --check
  * add config-file option
  * Fix Namespace check
  * Add --check-diff flag which combines check and diff
  * Use black for formatting code
  * Migrate to tomli
  * PEP 621: Migrate to pyproject.toml
  * Add option to keep pass statements
* Mon Jul 31 2023 Matej Cepl <mcepl@suse.com>
- Remove upstreamed patch rm_assert_failing_310.patch.
* Mon Sep 12 2022 Dirk Müller <dmueller@suse.com>
- reenable build for python38, issue got fixed in current release
* Fri Sep  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.5.3
  * test_autoflake: use os.linesep in assertion
  * Make sure messages use os.linesep
  * test_autoflake: add a test for #129
  * autoflake: propagate the exit status instead of calling sys.exit
  * Renamed the head branch
  * Remove Makefile and reference to travis.yml
- Update to v1.5.2
  * Remove usage of deprecated distutils module
  * Also add support for removing RHS of unused variables.
  * Use the new sysconfig module instead of distutils
  * added option to remove RHS also when removing unused variables (#92)
* Sun Aug 28 2022 Ben Greiner <code@bnavigator.de>
- Update to v1.5.1
  * support for reading configuration from setup.cfg and
    pyproject.toml
  * new flag `--quiet`
  * drop support for old versions of Python (<3.7)
  * support for reading contents from stdin (prints the output to
    stdout, ideal for integration with editors)
  * support for parallel execution with `--jobs`
- Skip building Python 3.8: gh#PyCQA/autoflake#100
* Wed Feb 23 2022 Matej Cepl <mcepl@suse.com>
- Skip failing test for Python 3.10 (gh#PyCQA/autoflake#104)
* Mon Aug 31 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.4:
  * No upstream changelog
- Switch from setup.py test to pytest
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.1:
  * no upstream changelog
* Thu May 16 2019 Meera Belur <mbelur@suse.com>
- Update to v1.3
  + No changes were provided
* Sun Feb 10 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.2
  + Have `standard_paths` look in both platform-specific and
    platform-independent directories
    (replaces fix_standard_paths.patch)
  + Add LICENSE
  + Drop Python 3.3
- Remove unnecessary build dependency %%pythons
- Remove unused build dependency 'coverage'
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May  9 2018 toddrme2178@gmail.com
- Add license file
- Use license tag
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
- Add fix_standard_paths.patch
  * Fix for https://github.com/myint/autoflake/issues/32
